/*
 * inetd/inetd.h --
 *
 *      Definitions of data types and functions shared across module
 *      boundaries.
 */

#include <stdlib.h>
#include <unistd.h>
#include <netdb.h>

#ifndef _INETD_H_
#define _INETD_H_

#define INETD_MAX_PARAM 256

typedef struct service
{
    char	   *port;
    char	   *name;
    char	   *params[INETD_MAX_PARAM];
    int		    socket;
    struct service *next;
} inetd_service_t;

extern inetd_service_t *inetd_services;

extern inetd_service_t *inetd_new_service();
extern void inetd_del_service(inetd_service_t *service);

typedef struct client
{
    pid_t	    pid;
    int		    socket;
    char            local_host[NI_MAXHOST];
    char            local_serv[NI_MAXSERV];
    char	    peer_host[NI_MAXHOST];
    char	    peer_serv[NI_MAXSERV];
    struct service *service;
    struct client  *next;
} inetd_client_t;

extern inetd_client_t *inetd_clients;

extern inetd_client_t *inetd_new_client(inetd_service_t *service);
extern void inetd_del_client(inetd_client_t *client);

extern void inetd_read_config(const char *filename);

extern void inetd_daemonize();
extern void inetd_signals();

#endif
